import * as React from 'react';
import { ReportData } from './report-data-typings';
import './Report.scss';
export declare const ReportContext: React.Context<{
    reportData: ReportData;
    currentTab: 'files' | 'details';
    setCurrentTab: (tab: "details" | "files" | ((prev: 'files' | 'details') => 'files' | 'details')) => void;
    searchString: string;
    setSearchString: (search: string) => void;
} | undefined>;
/**
 * `Report` is the root component where the report data should be passed.
 *
 * When `children` are not specified, a default sensible layout is shown.
 *
 * For extra flexibility (e.g. custom layouts, localization), the individual components can be passed as `children`
 * along with any additional elements. The report data is made available to child components through context so that
 * it does not need to be passed individually.
 *
 * @example
 * <Report data={reportData} />
 *
 * @example
 * <Report data={reportData}>
 *   <ReportTitle />
 *   <ReportTimestamp />
 *   <ReportBanner />
 *
 *   <div style={{ display: 'flex' }}>
 *     <ReportTablist />
 *     <ReportDebugIds />
 *   </div>
 *
 *   <ReportTabpanel>
 *     <FilesTable />
 *     <DetailsTable />
 *   </ReportTabpanel>
 * </Report>
 */
export declare const Report: ({ data, children, className, }: {
    /** The report data should be compatible with the type definitions. */
    data: ReportData;
    className?: string | undefined;
    children?: React.ReactNode;
}) => JSX.Element;
export default Report;
